@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: Interface.cpp,v 1.4 2006/03/06 03:00:50 vkurland Exp $
+  $Id: Interface.cpp,v 1.5 2006/09/10 22:40:37 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -61,7 +61,7 @@ Interface::Interface():Address()
     snmp_type        = -1   ;     
 }
 
-Interface::Interface(const FWObject *root) : Address(root)
+Interface::Interface(const FWObject *root,bool prepopulate) : Address(root,prepopulate)
 {
     setName("unknown");
     setBool("dyn",false);
